==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/ar/templates.php <==
<?php
regGS("The template $1 is in use and can not be deleted.", "القالب  1$ في حالة الاستخدام ولا يمكنت حذفه");
regGS("The folder could not be deleted.", "لا يمكن حذف المجلد");
regGS("The directory must be empty", "");
regGS("Create new folder", "اخلق مجلد جديد");
regGS("Upload template", "حمّل القالب");
regGS("Creating new folder", "خلق مجلد جديد");
regGS("You do not have the right to create new folders.", "لا تملك الصلاحية لخلق مجلدات جديدة");
regGS("The folder $1 could not be created", "المجلد 1$ لا يمكن خلقه");
regGS("A file or folder having the name $1 already exists", "الملف أو المجلد الذي لديه الاسم 1$ موجود");
regGS("You do not have the right to delete templates.", "لا تملك الصلاحية لحذف القوالب");
regGS("Are you sure you want to delete the folder $1 from $2?", "هل انت متأكد من حذف المجلد 1$ من 2$ ؟");
regGS("Are you sure you want to delete the template $1 from folder $2?", "هل أنت متأكد من حذف القالب 1$ من 2$ ؟");
regGS("Deleting template", "حذف القالب");
regGS("Deleting folder", "حذف المجلد");
regGS("The folder has been deleted.", "تم حذف المجلد");
regGS("The template has been deleted.", "تم إلغاء القالب");
regGS("The template could not be deleted.", "لا يمكن إلغاء القالب");
regGS("Template $1 was deleted", "تم حذف القالب $1");
regGS("Delete folder", "إلغاء المجلد");
regGS("Folders", "المجلدات");
regGS("No folders.", "لا بوجد مجلدات");
regGS("Files", "ملفات");
regGS("No templates.", "لا يوجد قوالب");
regGS("Uploading template", "تحميل القالب");
regGS("File", "ملف");
regGS("Create new template", "ضع قالب جديد");
regGS("Creating new template", "وضع قالب جديد");
regGS("Duplicate template", "كرر القالب");
regGS("Edit template", "تحرير القالب");
regGS("Save", "حفظ");
regGS("The template $1 has been created.", "القالب 1$ تم انشاؤه");
regGS("Do you want to edit the template ?", " هل تريد تحرير القالب؟");
regGS("The template $1 could not be created.", "لا يمكن وضع القالب 1$");
regGS("Template $1 was changed", "تمّ تغيير القالب 1$");
regGS("New template $1 was created", "تمّ وضع القالب جديد 1$");
regGS("Template $1 was duplicated into $2", "تمّ نسخ القالب 1$");
regGS("Template charset", "القالب");
regGS("Select a language/character set", "إختر لغة أو احرف اللغة");
regGS("All languages", "اللغات كلها");
regGS("You do not have the right to modify templates.", "لا تملك الصلاحية لتعديل القوالب");
regGS("Invalid template file $1", "ملف القالب 1$ خاطئ");
regGS("You do not have the right to create folders.", "لا تملك الصلاحية لخلق المجلدات");
regGS("You do not have the right to upload templates.", "لا تملك الصلاحية لتحميل القوالب");
regGS("You do not have the right to create templates.", "لا تملك الصلاحية لخبق القوالب");
regGS("Duplicate file", "تكرير الملف");
regGS("Delete file", "حذف الملف");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/ar/templates.php <==
<?php 
regGS("Template ID:", "");
regGS("Template ID", "");
regGS("Template $1 no longer exists!", "");
regGS("New template $1 created", "");
regGS("If the file you specified is a text file, you can convert its character set using the dropdown below.", "");
regGS("Directory $1 was deleted", "");
regGS("Directory $1 created.", "");
regGS("You must select a file to upload.", "");
regGS("You can only replace a file with a file of the same type.  The original file is of type \"$1\", and the file you uploaded was of type \"$2\".", "");
regGS("Unable to save the file '$1' to the path '$2'.", "");
regGS("Replace file:", "");
regGS("Replace", "");
regGS("File \"$1\" uploaded.", "");
regGS("File \"$1\" replaced.", "");
regGS("The folder name can't be '..' or '.'", "");
regGS("The template '$1' was saved successfully.", "تم حفظ القالب \"$1\" بنجاح.");
regGS("The template $1 is in use and can not be deleted.", "القالب  1$ في حالة الاستخدام ولا يمكنت حذفه");
regGS("Create new folder", "اخلق مجلد جديد");
regGS("Upload template", "حمّل القالب");
regGS("You do not have the right to create new folders.", "لا تملك الصلاحية لخلق مجلدات جديدة");
regGS("A file or folder having the name $1 already exists", "الملف أو المجلد الذي لديه الاسم 1$ موجود");
regGS("You do not have the right to delete templates.", "لا تملك الصلاحية لحذف القوالب");
regGS("Are you sure you want to delete the folder $1 from $2?", "هل انت متأكد من حذف المجلد 1$ من 2$ ؟");
regGS("Are you sure you want to delete the template $1 from folder $2?", "هل أنت متأكد من حذف القالب 1$ من 2$ ؟");
regGS("Template $1 was deleted", "تم حذف القالب $1");
regGS("Delete folder", "إلغاء المجلد");
regGS("Folders", "المجلدات");
regGS("No folders.", "لا بوجد مجلدات");
regGS("Files", "ملفات");
regGS("No templates.", "لا يوجد قوالب");
regGS("File", "ملف");
regGS("Create new template", "ضع قالب جديد");
regGS("Duplicate template", "كرر القالب");
regGS("Edit template", "تحرير القالب");
regGS("The template $1 could not be created.", "لا يمكن وضع القالب 1$");
regGS("Template $1 was changed", "تمّ تغيير القالب 1$");
regGS("Template $1 was duplicated into $2", "تمّ نسخ القالب 1$");
regGS("Template charset", "القالب");
regGS("Select a language/character set", "إختر لغة أو احرف اللغة");
regGS("All languages", "اللغات كلها");
regGS("You do not have the right to modify templates.", "لا تملك الصلاحية لتعديل القوالب");
regGS("Invalid template file $1", "ملف القالب 1$ خاطئ");
regGS("You do not have the right to create folders.", "لا تملك الصلاحية لخلق المجلدات");
regGS("You do not have the right to upload templates.", "لا تملك الصلاحية لتحميل القوالب");
regGS("You do not have the right to create templates.", "لا تملك الصلاحية لخبق القوالب");
regGS("Duplicate file", "تكرير الملف");
regGS("Delete file", "حذف الملف");
regGS("Please check if the user '$1' has permission to write in this directory.", "الرجاء التأكد من أن المستخدم \"$1\" لديه صلاحية الكتابة في هذا المجلد.");
regGS("The folder has been deleted.", "تم حذف المجلد");
regGS("The template has been deleted.", "تم إلغاء القالب");
regGS("The template could not be deleted.", "لا يمكن إلغاء القالب");
regGS("Save", "حفظ");
?>
